package com.ruoyi.interfaces.service;

import java.util.List;
import com.ruoyi.interfaces.domain.MdDataSetParam;

/**
 * 数据集参数Service接口
 * 
 * @author 朱得糠
 * @date 2025-09-03
 */
public interface IMdDataSetParamService 
{
    /**
     * 查询数据集参数
     * 
     * @param dcCode 数据集参数主键
     * @return 数据集参数
     */
    public MdDataSetParam selectMdDataSetParamByDcCode(String dcCode);

    /**
     * 查询数据集参数列表
     * 
     * @param mdDataSetParam 数据集参数
     * @return 数据集参数集合
     */
    public List<MdDataSetParam> selectMdDataSetParamList(MdDataSetParam mdDataSetParam);

    /**
     * 新增数据集参数
     * 
     * @param mdDataSetParam 数据集参数
     * @return 结果
     */
    public int insertMdDataSetParam(MdDataSetParam mdDataSetParam);

    /**
     * 修改数据集参数
     * 
     * @param mdDataSetParam 数据集参数
     * @return 结果
     */
    public int updateMdDataSetParam(MdDataSetParam mdDataSetParam);

    /**
     * 批量删除数据集参数
     * 
     * @param dcCodes 需要删除的数据集参数主键集合
     * @return 结果
     */
    public int deleteMdDataSetParamByDcCodes(String[] dcCodes);

    /**
     * 删除数据集参数信息
     * 
     * @param dcCode 数据集参数主键
     * @return 结果
     */
    public int deleteMdDataSetParamByDcCode(String dcCode);
}
